@@ -13,10 +13,10 @@ void assertEqualsImplCStr(const char* expected,const char* actual, long line, co
 	if (expected == actual) {} else {assertEqualsImplInt(expected,actual,__LINE__,__FILE__);return;}
 
 #define TEST_ASSERT_NULL(pointer)\
-	TEST_ASSERT_MESSAGE(pointer == NULL,#pointer " was not Null.")
+	TEST_ASSERT_MESSAGE(pointer == NULL,#pointer " was not null.")
 
 #define TEST_ASSERT_NOT_NULL(pointer)\
-	TEST_ASSERT_MESSAGE(pointer != NULL,#pointer " was Null.")
+	TEST_ASSERT_MESSAGE(pointer != NULL,#pointer " was null.")
 
 #define TEST_ASSERT_MESSAGE(x, msg)\
 	if (x) {} else {TEST_FAIL(msg);}
