@@ -9,12 +9,14 @@ char* TestCaller_name(TestCallerRef self)
 
 void TestCaller_run(TestCallerRef self,TestResultRef result)
 {
+	TestCase cs;
 	int i;
 	for (i=0; i<self->numberOfFixtuers; i++) {
-		TestCase cs = new_TestCase( self->fixtuers[i].name,
-									self->setUp,
-									self->tearDown,
-									self->fixtuers[i].test);
+		cs.isa	= (TestImplementRef)&TestCaseImplement;
+		cs.name	= self->fixtuers[i].name;
+		cs.setUp= self->setUp;
+		cs.tearDown	= self->tearDown;
+		cs.runTest	= self->fixtuers[i].test;
 		cs.isa->run(&cs,result);
 	}
 }
@@ -28,4 +30,4 @@ const TestImplement TestCallerImplement = {
 	(TestImplName)TestCaller_name,
 	(TestImplRun)TestCaller_run,
 	(TestImplCountTestCases)TestCaller_countTestCases,
-};
\ No newline at end of file
+};
